pub struct Entries;Trait Implementations
Sourceimpl GraphQLQuery for Entries
impl GraphQLQuery for Entries
Sourcetype Variables = Variables
type Variables = Variables
The shape of the variables expected by the query. This should be a generated struct most of the time.
Sourcetype ResponseData = ResponseData
type ResponseData = ResponseData
The top-level shape of the response data (the
data field in the GraphQL response). In practice this should be generated, since it is hard to write by hand without error.Auto Trait Implementations
impl Freeze for Entries
impl RefUnwindSafe for Entries
impl Send for Entries
impl Sync for Entries
impl Unpin for Entries
impl UnwindSafe for Entries