pub struct ExportSubscription;Trait Implementations
Sourceimpl GraphQLQuery for ExportSubscription
impl GraphQLQuery for ExportSubscription
Sourcetype Variables = Variables
type Variables = Variables
The shape of the variables expected by the query. This should be a generated struct most of the time.
Sourcetype ResponseData = ResponseData
type ResponseData = ResponseData
The top-level shape of the response data (the
data field in the GraphQL response). In practice this should be generated, since it is hard to write by hand without error.Auto Trait Implementations
impl Freeze for ExportSubscription
impl RefUnwindSafe for ExportSubscription
impl Send for ExportSubscription
impl Sync for ExportSubscription
impl Unpin for ExportSubscription
impl UnwindSafe for ExportSubscription