pub struct Subscription;Trait Implementations
Sourceimpl GraphQLQuery for Subscription
impl GraphQLQuery for Subscription
Sourcetype Variables = Variables
type Variables = Variables
The shape of the variables expected by the query. This should be a generated struct most of the time.
Sourcetype ResponseData = ResponseData
type ResponseData = ResponseData
The top-level shape of the response data (the
data field in the GraphQL response). In practice this should be generated, since it is hard to write by hand without error.Auto Trait Implementations
impl Freeze for Subscription
impl RefUnwindSafe for Subscription
impl Send for Subscription
impl Sync for Subscription
impl Unpin for Subscription
impl UnwindSafe for Subscription