pub struct ExportedFeed {
pub title: Option<String>,
pub url: FeedUrl,
pub requirement: Option<Requirement>,
pub category: Option<Category<'static>>,
}Fields
title: Option<String>url: FeedUrlrequirement: Option<Requirement>category: Option<Category<'static>>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for ExportedFeed
impl<'de> Deserialize<'de> for ExportedFeed
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<ExportSubscriptionOutputFeedsNodes> for ExportedFeed
impl From<ExportSubscriptionOutputFeedsNodes> for ExportedFeed
Sourcefn from(v: ExportSubscriptionOutputFeedsNodes) -> Self
fn from(v: ExportSubscriptionOutputFeedsNodes) -> Self
Converts to this type from the input type.
Sourceimpl From<ExportedFeed> for SubscribeFeedInput
impl From<ExportedFeed> for SubscribeFeedInput
Sourcefn from(feed: ExportedFeed) -> Self
fn from(feed: ExportedFeed) -> Self
Converts to this type from the input type.
Sourceimpl JsonSchema for ExportedFeed
impl JsonSchema for ExportedFeed
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ExportedFeed
impl RefUnwindSafe for ExportedFeed
impl Send for ExportedFeed
impl Sync for ExportedFeed
impl Unpin for ExportedFeed
impl UnwindSafe for ExportedFeed